@@ -16,11 +16,14 @@ def cli():
     parser = argparse.ArgumentParser(
         description=__doc__, formatter_class=argparse.RawDescriptionHelpFormatter
     )
+
     parser.add_argument(
         "source", help="URL or path to tabular file (CSV, XLS, etc.) to validate"
     )
     parser.add_argument("--log", default="WARNING", help="level of logging messages")
     parser.add_argument("--schema", help="URL or path to table schema JSON file")
+    parser.add_argument("--ignore_header_case", action='store_false', help="Cancel header case sensitivity",
+                        required=False)
     args = parser.parse_args()
 
     numeric_level = getattr(logging, args.log.upper(), None)
@@ -32,7 +35,7 @@ def cli():
         stream=sys.stderr,  # script outputs data
     )
 
-    report = validate(args.source, args.schema)
+    report = validate(args.source, args.schema, args.ignore_header_case)
 
     json.dump(report, sys.stdout, ensure_ascii=False, indent=2, sort_keys=True)
 
