@@ -1,7 +1,7 @@
 """Reimplementation of NonMatchingHeader check,
    taking into account missing header, extra header and wrong header order."""
 from frictionless import Check, errors
-
+from validata_core import helpers
 
 class MissingRequiredHeaderError(errors.HeaderError):
     """Custom error."""
@@ -28,8 +28,18 @@ class MissingRequiredHeader(Check):
         self.__required_field_names = self.get("required_field_names")
 
     def validate_start(self):
+
         for pos, field_name in enumerate(self.__required_field_names):
-            if field_name not in self.resource.header:
+            missing_required_header_error = False
+            if self.resource.header._Header__ignore_case:
+                lower_field_name = field_name.lower()
+                lower_resource_header = helpers.to_lower(self.resource.header)
+                if lower_field_name not in lower_resource_header:
+                    missing_required_header_error = True
+            elif field_name not in self.resource.header:
+                missing_required_header_error = True
+
+            if missing_required_header_error:
                 yield MissingRequiredHeaderError(
                     note=f"La colonne obligatoire `{field_name}` est manquante.",
                     labels=self.resource.header,
